@@ -1,9 +1,7 @@
 package Dist::Zilla::Plugin::NextVersion::Semantic;
-BEGIN {
-  $Dist::Zilla::Plugin::NextVersion::Semantic::AUTHORITY = 'cpan:YANICK';
-}
+our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: update the next version, semantic-wise
-$Dist::Zilla::Plugin::NextVersion::Semantic::VERSION = '0.2.4';
+$Dist::Zilla::Plugin::NextVersion::Semantic::VERSION = '0.2.5';
 use strict;
 use warnings;
 
@@ -86,7 +84,7 @@ sub before_release {
 
   my $changes = CPAN::Changes->load_string(
       $changes_file->content,
-      next_token => qr/{{\$NEXT}}/
+      next_token => qr/\{\{\$NEXT\}\}/
   );
 
   my( $next ) = reverse $changes->releases;
@@ -104,7 +102,7 @@ sub after_release {
 
   my $changes = CPAN::Changes->load(
       $self->change_file,
-      next_token => qr/{{\$NEXT}}/
+      next_token => qr/\{\{\$NEXT\}\}/
   );
 
   # remove empty groups
@@ -186,7 +184,7 @@ sub increment_level {
         or die "no changelog file found\n";
 
     my $changes = CPAN::Changes->load_string( $changes_file->content,
-        next_token => qr/{{\$NEXT}}/ );
+        next_token => qr/\{\{\$NEXT\}\}/ );
 
     my ($changelog) = reverse $changes->releases;
 
@@ -215,7 +213,7 @@ sub munge_files {
   return unless $file;
 
   my $changes = CPAN::Changes->load_string( $file->content,
-      next_token => qr/{{\$NEXT}}/
+      next_token => qr/\{\{\$NEXT\}\}/
   );
 
   my ( $next ) = reverse $changes->releases;
@@ -232,10 +230,8 @@ no Moose;
 
 {
     package Dist::Zilla::Plugin::NextVersion::Semantic::Incrementer;
-BEGIN {
-  $Dist::Zilla::Plugin::NextVersion::Semantic::Incrementer::AUTHORITY = 'cpan:YANICK';
-}
-$Dist::Zilla::Plugin::NextVersion::Semantic::Incrementer::VERSION = '0.2.4';
+our $AUTHORITY = 'cpan:YANICK';
+$Dist::Zilla::Plugin::NextVersion::Semantic::Incrementer::VERSION = '0.2.5';
 use List::AllUtils qw/ first_index any /;
 
     use Moose::Role;
@@ -290,6 +286,8 @@ use List::AllUtils qw/ first_index any /;
             }
         }
 
+        no warnings; # possible redundant args for sprintf
+
         my $version = sprintf $self->format, @version;
         $version =~ y/ //d;
 
@@ -314,7 +312,7 @@ Dist::Zilla::Plugin::NextVersion::Semantic - update the next version, semantic-w
 
 =head1 VERSION
 
-version 0.2.4
+version 0.2.5
 
 =head1 SYNOPSIS
 
