@@ -1,9 +1,7 @@
 package Dist::Zilla::Role::YANICK::PreviousVersionProvider;
-BEGIN {
-  $Dist::Zilla::Role::YANICK::PreviousVersionProvider::AUTHORITY = 'cpan:YANICK';
-}
+our $AUTHORITY = 'cpan:YANICK';
 #ABSTRACT: provides the distribution's previously released version
-$Dist::Zilla::Role::YANICK::PreviousVersionProvider::VERSION = '0.2.4';
+$Dist::Zilla::Role::YANICK::PreviousVersionProvider::VERSION = '0.2.5';
 
 use strict;
 use warnings;
@@ -27,7 +25,7 @@ Dist::Zilla::Role::YANICK::PreviousVersionProvider - provides the distribution's
 
 =head1 VERSION
 
-version 0.2.4
+version 0.2.5
 
 =head1 DESCRIPTION
 
